==> freedink-1.08.20080828.tar.gz: freedink-1.08.20080828/src/freedink_xpm.c <==
/**
 *  Converted from dink.ico, from the Dink source code release
 */

/*

*** Dink Smallwood Source License Information ***

This software is provided "as is" without express or implied
warranties. You may freely use, modify and distribute this
source provided that the copyright text below is included in
the resulting source code, for example:
"Portions Copyright (C) Seth A. Robinson, 1997-2003

You may use this source in personal and commercial products, you
are not required to release the source code.

Please note that sharing this source does not in any way relinquish interest or forfeit any rights enjoyed by
Robinson Technologies and Seth A. Robinson concerning the name Dink Smallwood and related media includeding graphics,
sounds, music, scripts and map data. (hereafter referred to as "Dink Smallwood Media").

Repackaging or distributing the Dink Smallwood Media in a modified format requires permission from
Seth A. Robinson.  Please consult the license included with the Dink Smallwood full version distribution for
more information.

Fastfile.*, ffcreate.*, dsutil.* and ddutil.* are copyrighted by the Microsoft Corporation and excluded
from the above license.

-Seth A. Robinson (seth@rtsoft.com)
www.rtsoft.com

*/

/* XPM */
char * freedink_xpm[] = {
"32 32 8 1",
" 	c None",
".	c #000000",
"+	c #808080",
"@	c #0000FF",
"#	c #808000",
"$	c #C0C0C0",
"%	c #800000",
"&	c #FFFFFF",
"       .                    ...+",
"      .@.                   .##.",
"     .@@@.           .     .####",
"     .@$@.          .#.   .##%..",
"    .@@$@@.         .##. .##%.  ",
"  ..@@$&$@@..########.##.##%.   ",
" .@@@$&&&$@@@.......#.###.%.    ",
".@@$$&&&&&$$@@@.%%%..$.###.     ",
" .@@@$&&&$@@@..%%%%.&&$.###.    ",
" #..@@$&$@@..%%%%%.&&$$&.###.   ",
" #.%.@@$@@.%%%%%%.&&$&&$...##.  ",
" #..%.@$@.%%%%%%.&&$&&$...#..   ",
" ##.%.@@@.%.....&&$&$$.%%.##    ",
"  #.%%.@.%%%.#.&&$&$$.%%%..##   ",
"  #.%%.@.%%%..&&$&$..%%%%%.##   ",
"  #.%%%.%%%..&&$&$.##.%%%%.##   ",
"  #...%%%...&.$&$.###.%%%%.##   ",
"  ###..%.#.#.#.$.#####.%%%.##   ",
"   ###.%%.#.#.#.######.%%.#.#   ",
"    ##.%%..#.#.#.#####.%%.#..#  ",
"   ##..%.&....................##",
"  ###.%.&$.%%%%%#%#%##%####.....",
" ##....&$&.#.#.#..............##",
"##..%.&$&.#.#.#.#####.%%%.#..#  ",
"#..%%.$$.#.#.#.#####.%%%..#.#   ",
"#.%%%..........#####.%%%.###    ",
"#.%%....%%%%%%%..#..%%%..#      ",
"#.%%.##..%%%%%%%%.%%%%..##      ",
"#.%..###..%%%%%%%%%%%..##       ",
"#...## ##...%%%%%%%...##        ",
"#####   ###.........###         ",
"          ###########           "};

==> freedink_108.4.orig.tar.gz: freedink-108.4/src/freedink_xpm.c <==
/**
 *  Converted from dink.ico, from the Dink source code release
 */

/*

*** Dink Smallwood Source License Information ***

This software is provided "as is" without express or implied
warranties. You may freely use, modify and distribute this
source provided that the copyright text below is included in
the resulting source code, for example:
"Portions Copyright (C) Seth A. Robinson, 1997-2003

You may use this source in personal and commercial products, you
are not required to release the source code.

Please note that sharing this source does not in any way relinquish interest or forfeit any rights enjoyed by
Robinson Technologies and Seth A. Robinson concerning the name Dink Smallwood and related media includeding graphics,
sounds, music, scripts and map data. (hereafter referred to as "Dink Smallwood Media").

Repackaging or distributing the Dink Smallwood Media in a modified format requires permission from
Seth A. Robinson.  Please consult the license included with the Dink Smallwood full version distribution for
more information.

Fastfile.*, ffcreate.*, dsutil.* and ddutil.* are copyrighted by the Microsoft Corporation and excluded
from the above license.

-Seth A. Robinson (seth@rtsoft.com)
www.rtsoft.com

*/

/*
In case this isn't clear enough, here's a statement of intent
clarifying that the icon is free and not covered by the stanza about
the "Dink Smallwood Media":
http://lists.gnu.org/archive/html/bug-freedink/2008-09/msg00008.html
*/

/* XPM */
char * freedink_xpm[] = {
"32 32 8 1",
" 	c None",
".	c #000000",
"+	c #808080",
"@	c #0000FF",
"#	c #808000",
"$	c #C0C0C0",
"%	c #800000",
"&	c #FFFFFF",
"       .                    ...+",
"      .@.                   .##.",
"     .@@@.           .     .####",
"     .@$@.          .#.   .##%..",
"    .@@$@@.         .##. .##%.  ",
"  ..@@$&$@@..########.##.##%.   ",
" .@@@$&&&$@@@.......#.###.%.    ",
".@@$$&&&&&$$@@@.%%%..$.###.     ",
" .@@@$&&&$@@@..%%%%.&&$.###.    ",
" #..@@$&$@@..%%%%%.&&$$&.###.   ",
" #.%.@@$@@.%%%%%%.&&$&&$...##.  ",
" #..%.@$@.%%%%%%.&&$&&$...#..   ",
" ##.%.@@@.%.....&&$&$$.%%.##    ",
"  #.%%.@.%%%.#.&&$&$$.%%%..##   ",
"  #.%%.@.%%%..&&$&$..%%%%%.##   ",
"  #.%%%.%%%..&&$&$.##.%%%%.##   ",
"  #...%%%...&.$&$.###.%%%%.##   ",
"  ###..%.#.#.#.$.#####.%%%.##   ",
"   ###.%%.#.#.#.######.%%.#.#   ",
"    ##.%%..#.#.#.#####.%%.#..#  ",
"   ##..%.&....................##",
"  ###.%.&$.%%%%%#%#%##%####.....",
" ##....&$&.#.#.#..............##",
"##..%.&$&.#.#.#.#####.%%%.#..#  ",
"#..%%.$$.#.#.#.#####.%%%..#.#   ",
"#.%%%..........#####.%%%.###    ",
"#.%%....%%%%%%%..#..%%%..#      ",
"#.%%.##..%%%%%%%%.%%%%..##      ",
"#.%..###..%%%%%%%%%%%..##       ",
"#...## ##...%%%%%%%...##        ",
"#####   ###.........###         ",
"          ###########           "};
